<div class="header_part p-2 border d-flex justify-content-between">
    <div class="left_header">
        <div class="btn-toolbar" role="toolbar">
            <div class="btn-group me-2">
                <button type="button" class="btn openMenuBar">
                    <i class="fa-solid fa-bars"></i>
                </button>
                <button type="button" class="btn redirectToRoot">
                    <i class="fa-solid fa-home"></i>
                    <span>Home</span>
                </button>
                <button type="button" class="btn addNewUpload">
                    <i class="fa-solid fa-cloud-arrow-up"></i>
                    <span>Upload</span>
                </button>
                <button type="button" class="btn addNewFolder">
                    <i class="fa-solid fa-folder-plus"></i>
                    <span>Add Folder </span>
                </button>

                <button type="button" class="btn refreshBtn">
                    <i class="fa-solid fa-rotate"></i>
                    <span>Refresh</span>
                </button>
            </div>
        </div>
    </div>

    <div class="right_header">
        <form method="get" class="filesSearchForm">
            <div class="input-group">
                <input type="search" name="s" class="form-control searchFilesInput" placeholder="Search" aria-label="Search">
            </div>
        </form>
    </div>
</div>