import type Notify from './index';
export declare const fadeIn: (self: Notify) => void;
export declare const fadeOut: (self: Notify) => void;
export declare const slideIn: (self: Notify) => void;
export declare const slideOut: (self: Notify) => void;
