#filemanager_tree {
    height: calc(100vh - 60px);
}

.header_part {
    position: sticky;
    top: 0;
    z-index: 999;
    background: #fff;
}

.filemanager_files_container {
    display: flex;
    justify-content: flex-start;
    align-items: center;
    gap: 15px;
    flex-wrap: wrap;
    padding-bottom: 4rem;
}

.filemanager_files_container .fm-item {
    cursor: pointer;
    position: relative;
    width: 140px;
    height: 140px;
    border-radius: 5px
}

.filemanager_files_container .fm-item-thumbnail {
    display: flex;
    justify-content: center;
    align-items: center;
    width: 100%;
    height: calc(140px - 30px);
    border-top-right-radius: 5px;
    border-top-left-radius: 5px;
    background-repeat: no-repeat;
    background-size: cover;
    background-position: center;
    font-size: 15px;
    color: #ccc;
    font-style: italic;
}

.filemanager_files_container .fm-item-title {
    display: block;
    height: 30px;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    text-align: center;
    color: #000;
    padding: 5px 10px;
    margin-bottom: 4px;
    font-size: 12px;
    border-top: 1px solid #ccc;
    width: 100%;
}

.btn:focus,
.btn:active,
.form-control:focus,
.form-control:active {
    outline: none;
    box-shadow: none;
}

.file-sorting-options .active,
.file-filtering-options .active {
    color: #1e2125;
    background-color: #e9ecef;
}

.file-sorting-options .dropdown-item.active,
.file-sorting-options .dropdown-item:active,
.file-filtering-options .dropdown-item.active,
.file-filtering-options .dropdown-item:active {
    color: #1e2125;
    background-color: #e9ecef;
}

#searchBtn,
#searchBtn:focus,
#searchBtn:active {
    border-color: #ced4da !important;
    background: none;
    outline: none;
    box-shadow: none;
    color: #545d67;
}

#filemanage_container {
    height: calc(100vh - 60px);
    overflow: hidden;
}

#filemanage_container {

}

#filemanage_container .list-group-item {
    padding: 5px 0;
}

.list-group-item .fa-folder {
    margin-right: 4px;
}

.list-group-item {
    cursor: pointer;
}

.list-group-item .fa-angle-right {
    transition: transform 0.2s ease-in-out;
}

.list-group-item:not(.collapsed)[data-bs-toggle] .fa-angle-right {
    transform: rotate(90deg);
}

.dropZone {
    padding: 2rem;
    text-align: center;
    border: 1px dashed #ccc;
    position: relative;
    margin: 0 auto;
}

.dropZone input {
    opacity: 0;
    position: absolute;
    z-index: 2;
    width: 100%;
    top: 0;
    left: 0;
}

.dropZone label {
    color: #fff;
    border-radius: 5px;
    background-color: var(--primary);
    padding: 8px 20px;
    margin-top: 0.5rem;
}

.dropZone h3 {
    font-size: 16px;
    font-weight: 600;
    color: #38424c;
}

.dropZone .fa-solid {
    font-size: 50px;
    margin-bottom: 1rem;
}


#fileUploadModal .files-list {
    margin-top: 1.5rem;
}

.fileIcon {
    font-size: 30px;
}

.single-file {
    display: flex;
    padding: 0.3rem 0.5rem;
    justify-content: space-between;
    align-items: center;
    border: dashed 1px #979797;
    margin-bottom: 1rem;
    gap: 10px;
    border-radius: 5px;
}

.single-file .progress {
    height: 4px;
}

.single-file .deleteFile {
    margin-left: 0.5rem;
    cursor: pointer;
}

.single-file .name {
    font-size: 14px;
    font-weight: 500;
    color: #353f4a;
    margin: 0;
}

.single-file .size {
    font-size: 12px;
    font-weight: 500;
    color: #a4a4a4;
    margin: 0;
    margin-bottom: 0.25rem;
}

.single-file .info {
    width: 100%
}

.btn-primary.disabled,
.btn-primary:disabled {
    color: #fff;
    background-color: var(--primary);
    border-color: var(--primary);
    opacity: 0.6;
}

.btn-primary,
.btn-primary:hover,
.btn-primary:focus,
.btn-primary:active {
    color: #fff;
    background-color: var(--primary);
    border-color: var(--primary);
}

.iconSpace {
    width: 16px;
    display: inline-block;
}

@media (min-width: 768px) {
    .col-md-2 {
        flex: 0 0 auto;
        width: 20%;
    }

    .col-md-10 {
        flex: 0 0 auto;
        width: 80%;
    }
}

.list-group-item.active {
    z-index: 2;
    color: rgb(255, 255, 255);
    background-color: var(--primary);
    border-color: var(--primary);
}

.context_menu button {
    cursor: pointer;
}

.no_files_and_folder_found {
    width: 100%;
    justify-content: center;
    display: flex;
    align-items: center;
    flex-direction: column;
    height: calc(100vh - 120px);
}

.no_files_and_folder_found .fa-folder {
    font-size: 80px;
    color: #8F8F8E;
}

.no_files_and_folder_found h3 {
    font-size: 25px;
    color: #8F8F8E;
    margin-top: 1rem;
}

.spinner {
    position: fixed;
    z-index: 99999;
    width: 100%;
    height: 100%;
    top: 0;
    display: none;
    justify-content: center;
    align-items: center;
    background: rgba(0, 0, 0, 0.5);
    font-size: 2rem;
    color: #000;
}

.spinner.absolute {
    position: absolute;
}

.spinner.show {
    display: flex;
}


.circle-line {
    display: flex;
    flex-wrap: wrap;
    justify-content: center;
}

.circle-red, .circle-green, .circle-yellow, .circle-blue {
    position: relative;
    width: 10px;
    height: 10px;
    border-radius: 30px;
    margin: 3px;
}

.circle-red {
    background-color: #EA4335;
    animation: movingUp 0.5s infinite alternate;

}

.circle-blue {
    background-color: #4285f4;
    animation: movingUp 0.5s 0.2s infinite alternate;

}

.circle-green {
    background-color: #34A853;
    animation: movingUp 0.5s .5s infinite alternate;


}

.circle-yellow {
    background-color: #FBBC05;
    animation: movingUp 0.5s .7s infinite alternate;
}

/* CSS ANIMATION */

@keyframes movingUp {
    from {

        top: 0px;

    }

    to {

        top: -15px;
    }
}

.breadcrumb-item.click {
    cursor: pointer;
}

@media (max-width: 700px) {
    .header_part .btn-toolbar button span {
        display: none;
    }
}

.openMenuBar {
    display: none;
}

@media (max-width: 766px) {
    #filemanager_sidebar {
        position: fixed;
        top: 0;
        width: 240px;
        background: #fff;
        height: 100vh;
        z-index: 99;
        padding-top: 60px;
        display: none;
    }

    .left_header {
        width: 100%;
    }

    .btn-toolbar,
    .btn-toolbar .btn-group {
        width: 100%;
        justify-content: space-between;
    }

    .openMenuBar {
        display: block;
    }

    .filemanager_content_top {
        padding-left: 1.5rem !important;
    }

    .filemanager_files_container .fm-item {
        width: 130px;
        height: 130px;
    }

    .filemanager_files_container .fm-item-thumbnail {
        height: calc(130px - 30px);
    }
}

.filemanager_content_top {
    position: sticky;
    top: 0;
    z-index: 999;
    background: #fff;
}

#filemanager_files {
    height: calc(100vh - 120px);
    overflow-y: auto;
    overflow-x: hidden;
}

@media (max-width: 400px) {
    .header_part .right_header {
        display: none;
    }

    .filemanager_content_top .right_part {
        display: none;
    }

    .filemanager_files_container .fm-item {
        width: 120px;
        height: 120px;
    }

    .filemanager_files_container .fm-item-thumbnail {
        height: calc(120px - 30px);
    }
}

.filemanager_files_container .fm-item .form-check {
    position: absolute;
    top: 0;
    left: 5px;
}

.select_files_container {
    position: fixed;
    bottom: 0;
    padding: 5px 10px;
    background: #fff;
    border-top: 1px solid #ccc;
    width: 100%;
}

[type="button"],
[type="button"]:focus,
[type="button"]:active {
    box-shadow: none;
    outline: none;
}

.table td {
    word-wrap: break-word;
    word-break: break-word;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: normal;
}

body a {
    color: var(--primary);
}

body .form-check-input:checked {
    background-color: var(--primary);
    border-color: var(--primary);
}

body .right_part .dropdown button {
    border-color: transparent !important;
}

#infoFileModal tr td {
    padding: 15px;
}

#infoFileModal tr td:first-child {
    min-width: 140px;
}

.file_uloading_corner_notification {
    position: fixed;
    bottom: 60px;
    right: -200%;
    min-width: 300px;
    background: #fff;
    transition: 0.5s all;
}

.file_uloading_corner_notification.uploading {
    right: 20px;
}

@media (max-width: 300px) {
    .file_uloading_corner_notification {
        min-width: calc(100% - 11px);
        right: 6px;
        bottom: 47px;
    }
}

.file_uloading_corner_notification .single-file {
    margin-bottom: 0;
}

.file_uloading_corner_notification .single-file {
    padding: 0.5rem 0.7rem;
}

.body_dragging {
    position: fixed;
    top: 0;
    left: 0;
    bottom: 0;
    right: 0;
    background: rgba(var(--primary-rgb), 0.6);
    z-index: 99999;
    display: none;
    align-items: center;
    justify-content: center;
    padding: 1rem;
}

.body_dragging > div {
    width: 100%;
    height: 100%;
    text-align: center;
    display: flex;
    align-items: center;
    justify-content: center;
    border: 4px dashed #fff;
    border-radius: 10px;
    color: #fff;
    font-size: 40px;
}

body.dragover {
    z-index: 9999;
}

body.dragover .body_dragging {
    display: flex;
}

@media (max-width: 500px) {
    .body_dragging > div {
        border-width: 2px;
        font-size: 20px;
    }
}

